@@ -1530,11 +1530,11 @@ def schedules_get(context, id_, team_name):
 @schedules.command(name='timeline')
 @click.option('--team-name', 'team_name', required=True)
 @click.option('--expand', type=click.Choice(['base', 'forwarding', 'override'], case_sensitive=False))
-@click.option('--interval')
-@click.option('--intervalunit')
+@click.option('--interval', default=1)
+@click.option('--intervalunit', default='months')
 @click.option('--history', is_flag=True)
 @click.pass_context
-def schedules_timeline(context, team_name, history, expand, interval=1, intervalunit="months"):  # pylint: disable=too-many-locals, too-many-arguments
+def schedules_timeline(context, team_name, history, expand, interval, intervalunit):  # pylint: disable=too-many-locals, too-many-arguments
     """
     Function to list the schedules for all teams
 
@@ -1558,7 +1558,6 @@ def schedules_timeline(context, team_name, history, expand, interval=1, interval
 
     for item in result['data'][f'{rotation}']['rotations'][0]['periods']:
         if not history and datetime.now().date() > datetime.strptime((item['startDate'].replace('Z', '')).split(".")[0], "%Y-%m-%dT%H:%M:%S").date():
-            print(item['startDate'])
             continue
         else:
             time_zone = pytz.timezone("UTC")
